@@ -1,7 +1,7 @@
 import os
 import shutil
 
-default_module_configs = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', 'config')
+default_module_configs = os.path.join(os.path.dirname(os.path.realpath(__file__)), '.', 'configs')
 
 def ensure_base_configs(config_dir: str):
     """
